import { setup } from '@storybook/vue3';
import { createNuxtApp, applyPlugins } from 'nuxt/app';
import { getContext } from 'unctx';
import { $fetch } from 'ofetch';
import { runtimeConfig } from 'virtual:nuxt-runtime-config';
import '#build/css';
import plugins from '#build/plugins';

const pluginsTyped = plugins;
setup(async (vueApp, storyContext) => {
  const key = storyContext?.id;
  if (!key) {
    throw new Error("StoryContext is not provided");
  }
  const appId = "nuxt-app";
  const globalCtx = getContext(appId);
  const storyNuxtAppName = `nuxt-app-${key}`;
  const storyNuxtCtx = getContext(storyNuxtAppName);
  if (storyNuxtCtx.tryUse()) {
    return;
  }
  window.__NUXT__ = {
    serverRendered: false,
    config: {
      public: {},
      app: { baseURL: "/" },
      ...runtimeConfig
    },
    data: {},
    state: {}
  };
  if (!globalThis.$fetch) {
    globalThis.$fetch = $fetch.create({
      baseURL: "/"
    });
  }
  const nuxt = createNuxtApp({
    vueApp,
    globalName: storyNuxtAppName
  });
  globalCtx.set(nuxt, true);
  await applyPlugins(nuxt, pluginsTyped);
  await nuxt.hooks.callHook("app:created", vueApp);
  await nuxt.hooks.callHook("app:beforeMount", vueApp);
});
